# Changelog

## [2.5.0](https://github.com/catppuccin/python/compare/v2.4.1...v2.5.0) (2025-08-03)


### Build System

* ignore `version` field in palette.json ([b5dad76](https://github.com/catppuccin/python/commit/b5dad762a71d6cab31561d58516a82c7b9c20a8b))


### Documentation

* document package with pdoc ([#108](https://github.com/catppuccin/python/issues/108)) ([e499070](https://github.com/catppuccin/python/commit/e49907013cedc45f61a0ce12f9d5849da40b06c9))


### Features

* auto-sync upstream palettes ([#107](https://github.com/catppuccin/python/issues/107)) ([900189a](https://github.com/catppuccin/python/commit/900189a21c3e5a0e7a7fd30ce89d440392322e57))


### Bug Fixes

* handle uppercase hexes from pygments ([#109](https://github.com/catppuccin/python/issues/109)) ([d06dedc](https://github.com/catppuccin/python/commit/d06dedc1155b037a40c2185f39ec799b9c864dd9))
* **pygments:** mantle for code block backgrounds ([#112](https://github.com/catppuccin/python/issues/112)) ([c7e72f8](https://github.com/catppuccin/python/commit/c7e72f8aaa763a776aaf672b609770d3d4e422ea))

## [2.4.1](https://github.com/catppuccin/python/compare/v2.4.0...v2.4.1) (2025-02-26)


### ci

* **release-please:** set `id-token: write` ([#103](https://github.com/catppuccin/python/issues/103)) ([df74a7e](https://github.com/catppuccin/python/commit/df74a7e13ed54b38ce4e310902edd63a20df139c))

## [2.4.0](https://github.com/catppuccin/python/compare/v2.3.4...v2.4.0) (2025-02-25)


### Build System

* switch to uv and drop python 3.8 support ([#100](https://github.com/catppuccin/python/issues/100)) ([ba03e0a](https://github.com/catppuccin/python/commit/ba03e0a1b3a252c36db2d4bdd67832bea4f2523e))


### Features

* **pygments:** remove line-height ([#86](https://github.com/catppuccin/python/issues/86)) ([368c755](https://github.com/catppuccin/python/commit/368c7552dbec69d71b21e68f0d403ff38e68707a))


### Bug Fixes

* **deps:** update dependency rich to v13.9.2 ([#83](https://github.com/catppuccin/python/issues/83)) ([73fc25e](https://github.com/catppuccin/python/commit/73fc25eef69f0188fc26f1814ce9793d63000556))

## [2.3.4](https://github.com/catppuccin/python/compare/v2.3.3...v2.3.4) (2024-09-08)


### Bug Fixes

* **extras/pygments:** change `Keyword.Reserved` from `pink` to `mauve` ([c0c3ee9](https://github.com/catppuccin/python/commit/c0c3ee990e5a36150f233ef61f1bae8cd4d09a59))
* **extras/pygments:** change `Name.Exception` from `text` to `yellow` ([c0c3ee9](https://github.com/catppuccin/python/commit/c0c3ee990e5a36150f233ef61f1bae8cd4d09a59))

## [2.3.3](https://github.com/catppuccin/python/compare/v2.3.2...v2.3.3) (2024-09-08)


### Bug Fixes

* **extras/pygments:** change `Name.Tag` from pink to blue ([#77](https://github.com/catppuccin/python/issues/77)) ([ecf1972](https://github.com/catppuccin/python/commit/ecf19729cbc53695db1fe3b0d0dfea5e5d84879e))
* **pygments:** functions should be `blue`, not `sapphire` ([#79](https://github.com/catppuccin/python/issues/79)) ([0bdf4e0](https://github.com/catppuccin/python/commit/0bdf4e025e960af010b79374c3a38caf53d372a4))

## [2.3.2](https://github.com/catppuccin/python/compare/v2.3.1...v2.3.2) (2024-09-08)


### Bug Fixes

* **extras/pygments:** align syntax highlighting tokens with style guide ([#75](https://github.com/catppuccin/python/issues/75)) ([2d0df3d](https://github.com/catppuccin/python/commit/2d0df3d746a9f6797c9e7b095cdf58ee41f56c72))

## [2.3.1](https://github.com/catppuccin/python/compare/v2.3.0...v2.3.1) (2024-09-04)


### Bug Fixes

* **deps:** update dependency matplotlib to v3.9.1 ([#56](https://github.com/catppuccin/python/issues/56)) ([ed3cc08](https://github.com/catppuccin/python/commit/ed3cc0849fec8948b3beed8bebce3d3387b198d0))
* **deps:** update dependency matplotlib to v3.9.2 ([#68](https://github.com/catppuccin/python/issues/68)) ([0d31bdb](https://github.com/catppuccin/python/commit/0d31bdbacaa5dc80073c317dd5105f6234f8016b))
* **deps:** update dependency rich to v13.8.0 ([#71](https://github.com/catppuccin/python/issues/71)) ([9f4ed60](https://github.com/catppuccin/python/commit/9f4ed60a81b316b2941f372669557b499f7a173f))
* **scripts/build-gh-pages:** add `code` selector for pygments styles ([#69](https://github.com/catppuccin/python/issues/69)) ([6699255](https://github.com/catppuccin/python/commit/6699255f59669cd044189c55afd141eba39c591a))


### Documentation

* move iterable docstring from Flavor to FlavorColors ([eaa1e45](https://github.com/catppuccin/python/commit/eaa1e459f64042c51a9fe2d19afb13eb7922cc2d))
* **readme:** add matplotlib contributors to thanks section ([1695f2f](https://github.com/catppuccin/python/commit/1695f2f47457d677836ba9c91134c7742cbb5981))

## [2.3.0](https://github.com/catppuccin/python/compare/v2.2.0...v2.3.0) (2024-06-18)


### Features

* added `matplotlib` support ([#36](https://github.com/catppuccin/python/issues/36)) ([580dabc](https://github.com/catppuccin/python/commit/580dabc3e3c15d9e3043430c100fb867f9847614))


### Bug Fixes

* **deps:** update dependency pygments to v2.18.0 ([#44](https://github.com/catppuccin/python/issues/44)) ([b40036e](https://github.com/catppuccin/python/commit/b40036e78929b965a90fabc728ea7da4e8e2beeb))
* **deps:** update dependency rich to v13.7.1 ([#39](https://github.com/catppuccin/python/issues/39)) ([f72ae06](https://github.com/catppuccin/python/commit/f72ae06336b0173fa525d2f93843216e87628673))
* **deps:** update dependency tinycss2 to v1.3.0 ([#45](https://github.com/catppuccin/python/issues/45)) ([c1e9d90](https://github.com/catppuccin/python/commit/c1e9d90229684944126abdaa8dac226625ec583e))


### Reverts

* **css:** remove extra `pre[lang]` selector ([#35](https://github.com/catppuccin/python/issues/35)) ([3fd71d3](https://github.com/catppuccin/python/commit/3fd71d31409f901a9c8048d57689a681a50baa12))
